save_model

Function save_model 

pub fn save_model(model: &Model, path: impl AsRef<Path>) -> Result<()>
Save a Model to a .onnx protobuf file (ONNX_RS 3.4).

Models loaded from protobuf or a textual protobuf codec preserve and write their complete source proto. Programmatically-built models serialize the shared execution graph and metadata.