pub fn from_text(source: &str) -> Result<Model>Expand description
Parse a model rendered by crate::text::to_text.
Binary initializer and tensor-attribute payloads are not present in the textual format. They are reconstructed as zero-filled placeholders with the printed dtype and shape; external initializers retain their external kind but necessarily use an empty path and zero offset.